@@ -1,15 +1,33 @@
 package Apache::Session::Browseable::Store::Redis;
 
 use strict;
-use Redis;
 
-our $VERSION = '0.1';
+our $VERSION = '1.2.2';
+our $redis;
+
+BEGIN {
+    $redis = 'Redis::Fast';
+    eval 'use Redis::Fast';
+    if ($@) {
+        require Redis;
+        $redis = 'Redis';
+    }
+}
 
 sub new {
     my ( $class, $session ) = @_;
     my $self;
 
-    $self->{cache} = Redis->new( %{ $session->{args} } );
+    # Manage undef encoding
+    $session->{args}->{encoding} = undef
+      if (  $session->{args}->{encoding}
+        and $session->{args}->{encoding} eq "undef" );
+
+    $self->{cache} = $redis->new( %{ $session->{args} } );
+
+    # Manage database
+    $self->{cache}->select( $session->{args}->{database} )
+      if defined $session->{args}->{database};
 
     bless $self, $class;
 }
@@ -63,7 +81,7 @@ __END__
 =head1 NAME
 
 Apache::Session::Browseable::Store::Redis - An implementation of
-Apache::Session::Browseable::Store
+Apache::Session::Store
 
 =head1 SYNOPSIS
 
@@ -79,11 +97,20 @@ Apache::Session::Browseable::Store
 This module is an implementation of Apache::Session::Browseable. It uses the
 Redis storage system
 
-=head1 AUTHOR
-
-This module was written by Xavier Guimard <x.guimard@free.fr>
-
 =head1 SEE ALSO
 
 L<Apache::Session::Browseable>, L<Apache::Session::NoSQL>, L<Apache::Session>
 
+=head1 AUTHOR
+
+This module was written by Xavier Guimard <x.guimard@free.fr>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2009-2018 by Xavier Guimard
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.10.1 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
